/*********************************************************

INCLUDE FILE: scores.agc
  by Steve Vink, September 2015
  Use permitted for all purposes, commercial and personal

  These functions perform the following:
  Initialising the Score module
  managing the Score increase
  Updating the Score
  
**********************************************************/


//*********************************************************
//  TYPE: 	tScore
//	      	used to manage the score
//    
//			currentScore
//			previousScore
//			displayedScore
//			speed
//*********************************************************
type tScore
	currentScore
	progressiveScore as float
	displayedScore
	speed as float
endtype

global gScore as tScore


//*********************************************************
function scoreInit(speed as float)
// Initialise the Score System
// The speed parameter dictates how quickly the speed will reach it's final value
// The higher the speed, the quicker it will reach the final value
// Maximum value is 100 (immediate update)
//*********************************************************
	
	gScore.currentScore = 0
	gScore.displayedScore = 0
	gScore.progressiveScore = 0
	
	scoreSetSpeed(speed)
	
endfunction


//*********************************************************
function scoreAddPoints(points as float)
//	Add points to the score
//*********************************************************

	inc gScore.currentScore, points
	
endfunction gScore.currentScore



//*********************************************************
function scoreGetScore()
//	Retrieve the actual score
//*********************************************************

endfunction gScore.currentScore



//*********************************************************
function scoreGetDisplayScore()
//	Retrieve the actual score
//*********************************************************

endfunction gScore.displayedScore



//*********************************************************
function scoreUpdate()
//	Update the display score and return it
//*********************************************************

	// If the score is up to date, return -1
	if gScore.displayedScore = gScore.currentScore
		exitfunction -1
	endif
	
	// The update speed is based on 60 FPS
	speed# = gScore.speed * (60 * GetFrameTime())
	
	//	Now find the amount to add to the dispalyed score
	inc gScore.progressiveScore, (gScore.currentScore - gScore.progressiveScore) * speed#
	if gScore.progressiveScore > gScore.currentScore then gScore.progressiveScore = gScore.currentScore
	
	//	Update the dispalyed score. We use the ceil() of the value to get an integer
	//	  value and ensure we reach the target
	gScore.displayedScore = ceil(gScore.progressiveScore)
	
endfunction gScore.displayedScore



//*********************************************************
function scoreSetSpeed(speed as float)
//	Change the speed of the score update
//*********************************************************

	gScore.speed = speed / 100.0
	
	if gScore.speed <= 0 then gScore.speed = 0.1
	if gScore.speed > 100 then gScore.speed = 100

endfunction


//*********************************************************
function scoreFormat(score,digits)
//	Creates a score string with leading digits
//*********************************************************

		score$ = str(score)
		for n = len(score$) to digits - 1
			score$ = "0" + score$
		next n

endfunction score$
